@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "annotation" "2.8.0"
+(define-package "annotation" "20250805.1029"
   "Functions for annotating text with faces and help bubbles."
   ()
   :url "https://github.com/agda/agda"
-  :commit "3d04bacca842729f9c0869b9287256321b5f450f"
-  :revdesc "v2.8.0-0-g3d04bacca842")
+  :commit "213db6e50bb89c1b0b2832eab4c6caafb137eb6d"
+  :revdesc "213db6e50bb8")
